@@ -1,9 +1,10 @@
 puts "<html><head>"
-puts "<style>\n  td { font-size: 12px; }\n  td.bright { color: #eee; }\n  td.dark { color: #222; }\n</style>"
+puts "<style>\n  td { font-size: 12px; text-align: center; padding-left: 3px; padding-right: 3px}"
+puts "  td.bright { color: #eee; }\n  td.dark { color: #222; }\n</style>"
 puts "</head><body>"
 puts "<table>"
 
-# we create a 8x8 table selecting a different background for each cell
+# we create a 9x9 table selecting a different background for each cell
 
 for {set i 0} { $i < 9 } {incr i} {
     puts "<tr>"
@@ -16,7 +17,7 @@ for {set i 0} { $i < 9 } {incr i} {
 # determining the background luminosity (YIQ space of NTSC) and choosing
 # the foreground color accordingly in order maintain maximum contrast
 
-        if { [expr ($r*0.29894)+($g*0.58704)+($b*0.11402)] > 128} {
+        if { [expr ($r*0.29894)+($g*0.58704)+($b*0.11402)] > 128.0} {
             set cssclass "dark"
         } else {
             set cssclass "bright"
