@@ -1,20 +1,23 @@
-# dio_Mysql.tcl -- Mysql backend.
+# -- dio_Mysql.tcl -- Mysql backend.
 
-# Copyright 2002-2004 The Apache Software Foundation
+#    Licensed to the Apache Software Foundation (ASF) under one
+#    or more contributor license agreements.  See the NOTICE file
+#    distributed with this work for additional information
+#    regarding copyright ownership.  The ASF licenses this file
+#    to you under the Apache License, Version 2.0 (the
+#    "License"); you may not use this file except in compliance
+#    with the License.  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing,
+#    software distributed under the License is distributed on an
+#    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#    KIND, either express or implied. See the License for the
+#    specific language governing permissions and limitations
+#    under the License.
 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-
-#       http://www.apache.org/licenses/LICENSE-2.0
-
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-# $Id: dio_Mysql.tcl 1807171 2017-09-03 22:14:34Z mxmanghi $
+# $Id$
 
 package provide dio_Mysql 0.3
 
@@ -31,8 +34,8 @@ namespace eval DIO {
 
             eval configure $args
 
-            if {[lempty $db]} {
-                if {[lempty $user]} {
+            if {[::rivet::lempty $db]} {
+                if {[::rivet::lempty $user]} {
                     set user $::env(USER)
                 }
                 set db $user
@@ -46,15 +49,15 @@ namespace eval DIO {
         method open {} {
             set command "mysqlconnect"
 
-            if {![lempty $user]} { lappend command -user $user }
-            if {![lempty $pass]} { lappend command -password $pass }
-            if {![lempty $port]} { lappend command -port $port }
-            if {![lempty $host]} { lappend command -host $host }
+            if {![::rivet::lempty $user]} { lappend command -user $user }
+            if {![::rivet::lempty $pass]} { lappend command -password $pass }
+            if {![::rivet::lempty $port]} { lappend command -port $port }
+            if {![::rivet::lempty $host]} { lappend command -host $host }
             if {[catch $command error]} { return -code error $error }
 
             set conn $error
 
-            if {![lempty $db]} { mysqluse $conn $db }
+            if {![::rivet::lempty $db]} { mysqluse $conn $db }
         }
 
         method close {} {
@@ -104,7 +107,7 @@ namespace eval DIO {
         }
 
         method sql_limit_syntax {limit {offset ""}} {
-            if {[lempty $offset]} {
+            if {[::rivet::lempty $offset]} {
                 return " LIMIT $limit"
             }
             return " LIMIT [expr $offset - 1],$limit"
