@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id: dio_Sqlite.tcl 1388916 2012-09-22 22:51:20Z mxmanghi $
+# $Id$
 
 package provide dio_Sqlite 0.1
 
@@ -88,7 +88,7 @@ namespace eval DIO {
 
         method sql_limit_syntax {limit {offset ""}} {
             set sql " LIMIT $limit"
-            if {![lempty $offset]} { append sql " OFFSET $offset" }
+            if {![::rivet::lempty $offset]} { append sql " OFFSET $offset" }
             return $sql
         }
 
