@@ -24,6 +24,12 @@
 
 #include <tcl.h>
 #include <string.h>
+/* Function prototypes are defined with EXTERN. Since we are in the same DLL,
+ * no need to keep this extern... */
+#ifdef EXTERN
+#   undef EXTERN
+#   define EXTERN
+#endif /* EXTERN */
 #include "rivet.h"
 #include "ap_config.h"
 
@@ -168,9 +174,9 @@ extern Tcl_Namespace* Rivet_GetNamespace( Tcl_Interp* interp);
 int
 Rivet_InitCrypt( Tcl_Interp *interp)
 {
-    RIVET_OBJ_CMD("encrypt", Rivet_EncryptCmd);
-    RIVET_OBJ_CMD("decrypt", Rivet_DecryptCmd);
-    RIVET_OBJ_CMD("crypt", Rivet_CryptCmd);
+    RIVET_OBJ_CMD("encrypt", Rivet_EncryptCmd,NULL);
+    RIVET_OBJ_CMD("decrypt", Rivet_DecryptCmd,NULL);
+    RIVET_OBJ_CMD("crypt", Rivet_CryptCmd,NULL);
 
 #if RIVET_NAMESPACE_EXPORT == 1
     {
@@ -178,10 +184,8 @@ Rivet_InitCrypt( Tcl_Interp *interp)
 
         RIVET_EXPORT_CMD(interp,rivet_ns,"encrypt");
         RIVET_EXPORT_CMD(interp,rivet_ns,"decrypt");
-        RIVET_EXPORT_CMD(interp,rivet_ns,"crypt");
-        
+        RIVET_EXPORT_CMD(interp,rivet_ns,"crypt");        
     }
 #endif
-
     return TCL_OK;
 }
